==> iiimf-skk-0.1.20.1.tar.gz: iiimf-skk-0.1.20.1/include/skk_xaux.h <==
/*
 * IIIMF-SKK, Japanese Language Engine for 
 *                        IIIMF (Internet/Intranet Input Method Framework)
 * 
 * Copyright (C) 2002 Motonobu Ichimura <famao@kondara.org>
 *
 * All rights reserved.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including
 * without limitation the rights to use, copy, modify, merge, publish,
 * distribute, and/or sell copies of the Software, and to permit persons
 * to whom the Software is furnished to do so, provided that the above
 * copyright notice(s) and this permission notice appear in all copies of
 * the Software and that both the above copyright notice(s) and this
 * permission notice appear in supporting documentation.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT
 * OF THIRD PARTY RIGHTS. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR
 * HOLDERS INCLUDED IN THIS NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL
 * INDIRECT OR CONSEQUENTIAL DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING
 * FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT,
 * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION
 * WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale, use
 * or other dealings in this Software without prior written authorization
 * of the copyright holder.
 *
 */

/* $Id: skk_xaux.h,v 1.2 2002/04/10 23:53:24 famao Exp $ */

/* vi:set ts=4 sw=4: */


/*
Copyright 1985, 1986, 1987, 1991, 1998  The Open Group

Portions Copyright 2000 Sun Microsystems, Inc. All Rights Reserved.

Permission is hereby granted, free of charge, to any person obtaining a
copy of this software and associated documentation files (the
"Software"), to deal in the Software without restriction, including
without limitation the rights to use, copy, modify, merge, publish,
distribute, sublicense, and/or sell copies of the Software, and to
permit persons to whom the Software is furnished to do so, subject to
the following conditions: The above copyright notice and this
permission notice shall be included in all copies or substantial
portions of the Software.


THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
IN NO EVENT SHALL THE OPEN GROUP OR SUN MICROSYSTEMS, INC. BE LIABLE
FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF
CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH
THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE EVEN IF
ADVISED IN ADVANCE OF THE POSSIBILITY OF SUCH DAMAGES.


Except as contained in this notice, the names of The Open Group and/or
Sun Microsystems, Inc. shall not be used in advertising or otherwise to
promote the sale, use or other dealings in this Software without prior
written authorization from The Open Group and/or Sun Microsystems,
Inc., as applicable.


X Window System is a trademark of The Open Group

OSF/1, OSF/Motif and Motif are registered trademarks, and OSF, the OSF
logo, LBX, X Window System, and Xinerama are trademarks of the Open
Group. All other trademarks and registered trademarks mentioned herein
are the property of their respective owners. No right, title or
interest in or to any trademark, service mark, logo or trade name of
Sun Microsystems, Inc. or its licensors is granted.

*/
/* ENGINE -> AUX */

#define	SKK_AUXPALETTE_START	1001
#define	SKK_AUXPALETTE_DONE	1002
#define	SKK_AUXPALETTE_CONVON	1003
#define	SKK_AUXPALETTE_CONVOFF	1004
#define	SKK_AUXPALETTE_HELPSTART	1005

/* Mode */
#define SKK_MODE_JMODE_HIRA	1500
#define SKK_MODE_JMODE_KATA 1501
#define SKK_MODE_ABBREV 1502
#define SKK_MODE_LATIN	1503
#define SKK_MODE_JISX0208_LATIN	1504
#define SKK_MODE_JISX0201_KANA 1505
#define SKK_MODE_OFF 1506

#define	SKK_AUXLUC_START	2001
#define	SKK_AUXLUC_DRAW	2002
#define	SKK_AUXLUC_DONE	2003
#define	SKK_AUXLUC_UPDATE	2004

/* AUX -> ENGINE */
#define SKK_AUXSETVAL_KEYPRESS	3001
#define SKK_AUX_CODE_DEFINED	3002
#define SKK_AUX_DICT_ADD		3003
#define SKK_AUX_PALETTE_CODE	3004

/* Initialize */
#define SKK_AUX_PALETTE_INIT	4000
#define SKK_AUX_PALETTE_OK	4001
#define SKK_AUX_DICT_INIT	4002
#define SKK_AUX_DICT_OK		4003
#define SKK_AUX_LUC_INIT	4004
#define SKK_AUX_LUC_OK	4005

#define SKK_AUX_PALETTE_CLASS_NAME "org.kondara.skk.PaletteAux"
#define SKK_AUX_LUC_CLASS_NAME     "org.kondara.skk.LookupAux"
#define SKK_AUX_ADD_DICT_CLASS_NAME "org.kondara.skk.AddDictAux"

==> iiimf-skk-0.1.22.90.tar.gz: iiimf-skk-0.1.22.90/include/skk_xaux.h <==
/*
 * IIIMF-SKK, Japanese Language Engine for 
 *                        IIIMF (Internet/Intranet Input Method Framework)
 * 
 * Copyright (C) 2003 Motonobu Ichimura <famao@momonga-linux.org>
 * Copyright (C) 2002 Motonobu Ichimura <famao@kondara.org>
 *
 * All rights reserved.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including
 * without limitation the rights to use, copy, modify, merge, publish,
 * distribute, and/or sell copies of the Software, and to permit persons
 * to whom the Software is furnished to do so, provided that the above
 * copyright notice(s) and this permission notice appear in all copies of
 * the Software and that both the above copyright notice(s) and this
 * permission notice appear in supporting documentation.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT
 * OF THIRD PARTY RIGHTS. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR
 * HOLDERS INCLUDED IN THIS NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL
 * INDIRECT OR CONSEQUENTIAL DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING
 * FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT,
 * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION
 * WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale, use
 * or other dealings in this Software without prior written authorization
 * of the copyright holder.
 *
 */

/* $Id: skk_xaux.h,v 1.2.2.2 2003/02/07 09:20:32 famao Exp $ */

/* vi:set ts=4 sw=4: */


/*
Copyright 1985, 1986, 1987, 1991, 1998  The Open Group

Portions Copyright 2000 Sun Microsystems, Inc. All Rights Reserved.

Permission is hereby granted, free of charge, to any person obtaining a
copy of this software and associated documentation files (the
"Software"), to deal in the Software without restriction, including
without limitation the rights to use, copy, modify, merge, publish,
distribute, sublicense, and/or sell copies of the Software, and to
permit persons to whom the Software is furnished to do so, subject to
the following conditions: The above copyright notice and this
permission notice shall be included in all copies or substantial
portions of the Software.


THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
IN NO EVENT SHALL THE OPEN GROUP OR SUN MICROSYSTEMS, INC. BE LIABLE
FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF
CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH
THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE EVEN IF
ADVISED IN ADVANCE OF THE POSSIBILITY OF SUCH DAMAGES.


Except as contained in this notice, the names of The Open Group and/or
Sun Microsystems, Inc. shall not be used in advertising or otherwise to
promote the sale, use or other dealings in this Software without prior
written authorization from The Open Group and/or Sun Microsystems,
Inc., as applicable.


X Window System is a trademark of The Open Group

OSF/1, OSF/Motif and Motif are registered trademarks, and OSF, the OSF
logo, LBX, X Window System, and Xinerama are trademarks of the Open
Group. All other trademarks and registered trademarks mentioned herein
are the property of their respective owners. No right, title or
interest in or to any trademark, service mark, logo or trade name of
Sun Microsystems, Inc. or its licensors is granted.

*/
/* ENGINE -> AUX */

#define	SKK_AUXPALETTE_START	1001
#define	SKK_AUXPALETTE_DONE	1002
#define	SKK_AUXPALETTE_CONVON	1003
#define	SKK_AUXPALETTE_CONVOFF	1004
#define	SKK_AUXPALETTE_HELPSTART	1005

/* Mode */
#define SKK_MODE_JMODE_HIRA	1500
#define SKK_MODE_JMODE_KATA 1501
#define SKK_MODE_ABBREV 1502
#define SKK_MODE_LATIN	1503
#define SKK_MODE_JISX0208_LATIN	1504
#define SKK_MODE_JISX0201_KANA 1505
#define SKK_MODE_OFF 1506

#define	SKK_AUXLUC_START	2001
#define	SKK_AUXLUC_DRAW	2002
#define	SKK_AUXLUC_DONE	2003
#define	SKK_AUXLUC_UPDATE	2004

/* AUX -> ENGINE */
#define SKK_AUXSETVAL_KEYPRESS	3001
#define SKK_AUX_CODE_DEFINED	3002
#define SKK_AUX_DICT_ADD		3003
#define SKK_AUX_PALETTE_CODE	3004

/* Initialize */
#define SKK_AUX_PALETTE_INIT	4000
#define SKK_AUX_PALETTE_OK	4001
#define SKK_AUX_DICT_INIT	4002
#define SKK_AUX_DICT_OK		4003
#define SKK_AUX_LUC_INIT	4004
#define SKK_AUX_LUC_OK	4005
#define SKK_AUX_RELOAD_CONFIG 4006

#define SKK_AUX_PALETTE_CLASS_NAME "org.momonga-linux.skk.PaletteAux"
#define SKK_AUX_LUC_CLASS_NAME     "org.momonga-linux.skk.LookupAux"
#define SKK_AUX_ADD_DICT_CLASS_NAME "org.momonga-linux.skk.AddDictAux"
